==> certmanager-model-v1-5.10.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1/OrderStatusBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OrderStatusBuilder extends io.fabric8.certmanager.api.model.acme.v1.OrderStatusFluentImpl<io.fabric8.certmanager.api.model.acme.v1.OrderStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.certmanager.api.model.acme.v1.OrderStatus,io.fabric8.certmanager.api.model.acme.v1.OrderStatusBuilder>{
  public OrderStatusBuilder() {
    this(false);
  }
  public OrderStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new OrderStatus(), validationEnabled);
  }
  public OrderStatusBuilder(io.fabric8.certmanager.api.model.acme.v1.OrderStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public OrderStatusBuilder(io.fabric8.certmanager.api.model.acme.v1.OrderStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OrderStatus(), validationEnabled);
  }
  public OrderStatusBuilder(io.fabric8.certmanager.api.model.acme.v1.OrderStatusFluent<?> fluent,io.fabric8.certmanager.api.model.acme.v1.OrderStatus instance) {
    this(fluent, instance, false);
  }
  public OrderStatusBuilder(io.fabric8.certmanager.api.model.acme.v1.OrderStatusFluent<?> fluent,io.fabric8.certmanager.api.model.acme.v1.OrderStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAuthorizations(instance.getAuthorizations()); 
    fluent.withCertificate(instance.getCertificate()); 
    fluent.withFailureTime(instance.getFailureTime()); 
    fluent.withFinalizeURL(instance.getFinalizeURL()); 
    fluent.withReason(instance.getReason()); 
    fluent.withState(instance.getState()); 
    fluent.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  public OrderStatusBuilder(io.fabric8.certmanager.api.model.acme.v1.OrderStatus instance) {
    this(instance,false);
  }
  public OrderStatusBuilder(io.fabric8.certmanager.api.model.acme.v1.OrderStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAuthorizations(instance.getAuthorizations()); 
    this.withCertificate(instance.getCertificate()); 
    this.withFailureTime(instance.getFailureTime()); 
    this.withFinalizeURL(instance.getFinalizeURL()); 
    this.withReason(instance.getReason()); 
    this.withState(instance.getState()); 
    this.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.certmanager.api.model.acme.v1.OrderStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.certmanager.api.model.acme.v1.OrderStatus build() {
    OrderStatus buildable = new OrderStatus(fluent.getAuthorizations(),fluent.getCertificate(),fluent.getFailureTime(),fluent.getFinalizeURL(),fluent.getReason(),fluent.getState(),fluent.getUrl());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OrderStatusBuilder that = (OrderStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> certmanager-model-v1-6.2.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1/OrderStatusBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OrderStatusBuilder extends OrderStatusFluentImpl<OrderStatusBuilder> implements VisitableBuilder<OrderStatus,OrderStatusBuilder>{
  public OrderStatusBuilder() {
    this(false);
  }
  public OrderStatusBuilder(Boolean validationEnabled) {
    this(new OrderStatus(), validationEnabled);
  }
  public OrderStatusBuilder(OrderStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public OrderStatusBuilder(OrderStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OrderStatus(), validationEnabled);
  }
  public OrderStatusBuilder(OrderStatusFluent<?> fluent,OrderStatus instance) {
    this(fluent, instance, false);
  }
  public OrderStatusBuilder(OrderStatusFluent<?> fluent,OrderStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAuthorizations(instance.getAuthorizations()); 
    fluent.withCertificate(instance.getCertificate()); 
    fluent.withFailureTime(instance.getFailureTime()); 
    fluent.withFinalizeURL(instance.getFinalizeURL()); 
    fluent.withReason(instance.getReason()); 
    fluent.withState(instance.getState()); 
    fluent.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  public OrderStatusBuilder(OrderStatus instance) {
    this(instance,false);
  }
  public OrderStatusBuilder(OrderStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAuthorizations(instance.getAuthorizations()); 
    this.withCertificate(instance.getCertificate()); 
    this.withFailureTime(instance.getFailureTime()); 
    this.withFinalizeURL(instance.getFinalizeURL()); 
    this.withReason(instance.getReason()); 
    this.withState(instance.getState()); 
    this.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  OrderStatusFluent<?> fluent;
  Boolean validationEnabled;
  public OrderStatus build() {
    OrderStatus buildable = new OrderStatus(fluent.getAuthorizations(),fluent.getCertificate(),fluent.getFailureTime(),fluent.getFinalizeURL(),fluent.getReason(),fluent.getState(),fluent.getUrl());
    return buildable;
  }
  
}
